summaryrefslogtreecommitdiff
path: root/Makefile.SH
diff options
context:
space:
mode:
authorGurusamy Sarathy <gsar@cpan.org>1998-05-29 02:31:44 +0000
committerGurusamy Sarathy <gsar@cpan.org>1998-05-29 02:31:44 +0000
commit1d2dff63f533f62282a700198c67c41dcb6ad6df (patch)
tree7eac820768f3a944fd0395294df59cec1ad9bedc /Makefile.SH
parentbe44fb0e48bd19a864cf6b6d066beef8e960db7d (diff)
downloadperl-1d2dff63f533f62282a700198c67c41dcb6ad6df.tar.gz
[win32] merge changes#1014,1038 from maintbranch
p4raw-link: @1038 on //depot/maint-5.004/perl: c3cf4c2be38f0215f451c3dd6cb13089e5f2329f p4raw-link: @1014 on //depot/maint-5.004/perl: d14230f9721c31ac6e9e2fdb706c7fc95118b4e6 p4raw-id: //depot/win32/perl@1052
Diffstat (limited to 'Makefile.SH')
-rw-r--r--Makefile.SH7
1 files changed, 5 insertions, 2 deletions
diff --git a/Makefile.SH b/Makefile.SH
index a70b53e4fe..4f78f57d74 100644
--- a/Makefile.SH
+++ b/Makefile.SH
@@ -552,7 +552,7 @@ depend: makedepend
makedepend: makedepend.SH config.sh
sh ./makedepend.SH
-test-prep: miniperl perl preplibrary $(dynamic_ext)
+test-prep: miniperl perl preplibrary utilities $(dynamic_ext)
cd t && (rm -f perl$(EXE_EXT); $(LNS) ../perl$(EXE_EXT) perl$(EXE_EXT))
test check: test-prep
@@ -573,10 +573,13 @@ minitest: miniperl
# Handy way to run perlbug -ok without having to install and run the
# installed perlbug. We don't re-run the tests here - we trust the user.
# Please *don't* use this unless all tests pass.
# If you want to report test failures, just use "perlbug -Ilib".
ok: utilities
$(LBLIBPTH) ./perl -Ilib utils/perlbug -ok -s '(UNINSTALLED)'
+nok: utilities
+ $(LBLIBPTH) ./perl -Ilib utils/perlbug -nok -s '(UNINSTALLED)'
+
clist: $(c)
echo $(c) | tr ' ' '\012' >.clist
@@ -573,10 +573,13 @@ minitest: miniperl
# installed perlbug. We don't re-run the tests here - we trust the user.
# Please *don't* use this unless all tests pass.
-# If you want to report test failures, just use "perlbug -Ilib".
+# If you want to report test failures, use "make nok" instead.
ok: utilities
$(LBLIBPTH) ./perl -Ilib utils/perlbug -ok -s '(UNINSTALLED)'